@@ -30,15 +30,14 @@ cdm_sample_person <- function(cdm, person_subset) {
     dplyr::pull("cdmTableName") %>%
     unique()
 
-  cdm2 <- purrr::map(names(cdm), function(nm) {
+  cdm2 <- cdm
+  for (nm in names(cdm)) {
     if (nm %in% tables_to_subset) {
-      dplyr::inner_join(cdm[[nm]], person_subset, by = "person_id")
+      cdm2[[nm]] <- dplyr::inner_join(cdm[[nm]], person_subset, by = "person_id")
     } else if ("subject_id" %in% colnames(cdm[[nm]])) {
-      dplyr::inner_join(cdm[[nm]], person_subset, by = c("subject_id" = "person_id"))
-    } else {
-      cdm[[nm]]
+      cdm2[[nm]] <- dplyr::inner_join(cdm[[nm]], person_subset, by = c("subject_id" = "person_id"))
     }
-  })
+  }
 
   # TODO: need to subset and copy cohort tables
   attributes(cdm2) <- attributes(cdm)
